# Serialization Tools
 Small collection of python snippets I reuse in file format dumping

## Installation (Pip)
### Installing from PyPI (Recommended)
```
pip install mak-serialization-tools
```
### Installing from GitHub<br>
For more information, see [pip VCS support](https://pip.pypa.io/en/stable/topics/vcs-support/#git)
```
pip install git+https://github.com/ModernMAK/Serialization-Tools
```
